install:
	@npm install

update:
	@npm prune && npm install

install-scripts:
	@node -e "\
		var pkg = require('./package.json');\
		pkg.scripts = pkg.scripts || {};\
		pkg.scripts.lint = 'make lint';\
		pkg.scripts.build = 'make build';\
		pkg.scripts.postpublish =  'make post-publish';\
		pkg.scripts.preversion = 'make pre-version';\
		pkg.scripts.test = 'make test';\
		pkg.scripts.version = 'make version';\
		pkg.scripts.watch = 'make watch';\
		var s = JSON.stringify(pkg, null, 2);\
		require('fs').writeFileSync('./package.json', s);"

pre-version: lint build test
	@[[ -z $$(git status --porcelain) ]] || (echo "Git working directory not clean."; exit 1)

version: lint
	git --no-pager log --reverse --format='%aN <%aE>' | sort -fub > AUTHORS && git add AUTHORS && git commit -m \"update AUTHORS\" AUTHORS || true
	@VERSION=`node -pe "require('./package.json').version"` && \
	echo "### v$$VERSION\n" > \#temp_changelog
	@GITHUBREPO=`node -pe "require('./package.json').repository"` && \
	git log `git rev-list --tags --max-count=1`..HEAD --pretty=format:"- [\`%h\`](https://github.com/$$GITHUBREPO/commit/%H) %s (%an)" --reverse >> \#temp_changelog
	nano \#temp_changelog
	echo "\n" >> \#temp_changelog
	cat CHANGELOG.md >> \#temp_changelog || true
	mv -f \#temp_changelog CHANGELOG.md
	git add CHANGELOG.md

post-publish:
	@VERSION=`node -pe "require('./package.json').version"` && \
	git push origin HEAD:master v$$VERSION
