.PHONY: test watch clean default

BIN = ''

# with npm run
ifeq ($(origin npm_package_version), undefined)
	BIN = node_modules/.bin/
endif

include node_modules/springbokjs-library/_tasks-common.mk

init: install-dependencies install-config-files install-scripts install-githooks

install-dependencies:
	npm install --save-dev eslint eslint-config-pob

install-config-files:
	rm -i .jscsrc .jshintrc .eslintrc .eslintignore .babelrc .babelrc-browser .npmignore || echo
	cp node_modules/springbokjs-library/config-files/gitignore .gitignore || echo
	ln -s node_modules/springbokjs-library/config-files/.npmignore || echo
	ln -s node_modules/springbokjs-library/config-files/.babelrc || echo
	cp node_modules/springbokjs-library/config-files/.eslintrc . || echo
	ln -s node_modules/springbokjs-library/.eslintignore || echo
	cp node_modules/springbokjs-library/config-files/jsdoc.conf.json . || echo

copy-config-files:
	# cp node_modules/springbokjs-library/.jscsrc .jscsrc || echo
	cp node_modules/springbokjs-library/.gitignore .gitignore || echo
	cp node_modules/springbokjs-library/config-files/.npmignore .npmignore || echo
	cp node_modules/springbokjs-library/config-files/.babelrc .babelrc || echo
	cp node_modules/springbokjs-library/.eslintrc .eslintrc || echo
	cp node_modules/springbokjs-library/.eslintignore .eslintignore || echo
	cp node_modules/springbokjs-library/config-files/jsdoc.conf.json . || echo

install-githooks:
	ln -s node_modules/springbokjs-library/git-hooks/pre-commit .git/hooks/pre-commit || echo

default: watch

clean:
	rm -Rf docs lib lib-cov test/lib dist coverage browser/lib
	@mkdir -p test/src test/src browser/lib

build: clean rebuild ;

JS_SRC = $(wildcard src/*.js)
JS_LIB = $(JS_SRC:src/%.js=lib/%.js)

JS_TEST_SRC = $(wildcard test/src/*.js)
JS_TEST_LIB = $(JS_TEST_SRC:test/src/%.js=test/lib/%.js)

lib: $(JS_LIB)
lib/%.js: src/%.js
	mkdir -p $(@D)
	$(BIN)babel -b regenerator $< -o $@

test/lib: $(JS_TEST_LIB)
test/lib/%.js: test/src/%.js
	mkdir -p $(@D)
	$(BIN)babel -b regenerator $< -o $@

all: lib test/lib

docs: api test-coverage;

api:
	rm -Rf docs/
	$(BIN)jsdoc README.md lib/ --recurse --destination docs/ --configure jsdoc.conf.json

lint:
	@echo "> Lint files"
	@echo '>> eslint';
	$(BIN)eslint -c .eslintrc src/ test/src/
	@if [ -e src/.flowconfig ]; \
	then \
		echo '>> flow'; \
		flow check --all src; \
	fi

lint-fix:
	$(BIN)eslint -c .eslintrc --fix src/ test/src/

test:
	@echo "> Run test"
	@if [ -d test/lib ]; \
	then \
		$(BIN)mocha --harmony --es_staging --recursive --bail -u tdd test/lib; \
	else \
		echo '[WARN] No tests.'; \
	fi
ifneq ("$(wildcard ./karma.conf.js)","")
	make browser-test
endif

build-browser-test:
	@echo "> Browser test"
	@mkdir -p dist
	$(BIN)browserify -d -e test/browser/index.js -o dist/test.js -t [ babelify --presets [ es2015 ] ]

browser-test: build-browser-test
	@echo "> Browser test: run karma"
	$(BIN)karma run

test-coverage:
	@echo "> Tests coverage (coverage/lcov-report/)"
	rm -Rf coverage/
	node --harmony --es_staging node_modules/istanbul/lib/cli.js cover node_modules/.bin/_mocha -- --recursive --reporter=spec -u tdd test/lib
